==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/lsfunctions/TRIPTimerAgent.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */
static const char* const TRIPTimerAgent_cxx_Version = 
"$Id: TRIPTimerAgent.cxx,v 1.6 2000/11/13 21:32:34 kevin Exp $";
#include <stdio.h>

#include "TRIPTimer.hxx"
#include "cpLog.h"
#include "TRIPTimerAgent.hxx"
#include "LSPeerSession.hxx"


TRIPTimerAgent::TRIPTimerAgent(LSPeerSession& session) : itsSession(session)
{
    itsTimer = new TRIPTimer();
    durationInMs = 0;
}


void
TRIPTimerAgent::startTimer( )
{
    assert( itsTimer != 0 );
    itsTimer->startTimer( *this, durationInMs );
}

void
TRIPTimerAgent::cancelTimer() // cancel the timer before the time elapses
{
    assert( itsTimer != 0 );
    itsTimer->cancelTimer();
}

void
TRIPTimerAgent::clearTimer() // clear the timer id 
{
    assert( itsTimer != 0 );
    itsTimer->clearTimerId();
}

void
TRIPTimerAgent::setDuration( const int timerMs )
{
    durationInMs = timerMs;
}

const int
TRIPTimerAgent::getDuration( )
{
    return durationInMs;
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/lsfunctions/TRIPTimerAgent.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */
static const char* const TRIPTimerAgent_cxx_Version = 
"$Id: TRIPTimerAgent.cxx,v 1.10 2001/01/03 22:57:41 sprajpat Exp $";
#include <stdio.h>

#include "TRIPTimer.hxx"
#include "cpLog.h"
#include "TRIPTimerAgent.hxx"
#include "LSPeerSession.hxx"


TRIPTimerAgent::TRIPTimerAgent()
{
    itsTimer = new TRIPTimer();
    durationInMs = 0;
}


void
TRIPTimerAgent::startTimer( )
{
    assert( itsTimer.getPtr());
    itsTimer->startTimer( *this, durationInMs );
}

void
TRIPTimerAgent::cancelTimer() // cancel the timer before the time elapses
{
    cpLog(LOG_DEBUG, "%s:cancelTimer()", className().c_str());
    assert( itsTimer.getPtr());
    itsTimer->cancelTimer();
}

void
TRIPTimerAgent::clearTimer() // clear the timer id 
{
    assert( itsTimer.getPtr() );
    itsTimer->clearTimerId();
}

void
TRIPTimerAgent::setDuration( const int timerMs )
{
    durationInMs = timerMs;
}

const int
TRIPTimerAgent::getDuration( )
{
    return durationInMs;
}
